"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const map_1 = require("@code-dependency/map");
const chalk_1 = require("chalk");
const fs = require("fs");
const open = require("open");
const path = require("path");
const filesystem_1 = require("./filesystem");
const server_1 = require("./server");
const getFlatDependencies = (cwd, fileName, stripBasePath, options) => {
    const source = path.resolve(cwd, path.normalize(fileName));
    if (!filesystem_1.existFile(source)) {
        console.log(chalk_1.default.black.bgRed(" Not fount "), chalk_1.default.red(`${source}`));
        process.exit();
    }
    else {
        console.log(chalk_1.default.black.bgGreen(" Load "), chalk_1.default.green(`${source}`));
    }
    return () => map_1.getDependencies({ source, executeDirectory: cwd, stripBasePath }, options);
};
const getBasePath = (cwd, target) => {
    const source = path.resolve(cwd, path.normalize(target));
    const diff = path.relative(cwd, source);
    return path.dirname(path.join(cwd, diff));
};
exports.startServeMessage = (address) => {
    console.log("");
    console.log("  ", chalk_1.default.blue(`Server      : ${address}`));
    console.log("  ", chalk_1.default.blue(`API Server  : ${address}/api`));
    console.log("");
    open(address);
};
exports.startProjectServe = async (project, cwd, options, cut, port = 7000) => {
    const stripBasePath = cut ? getBasePath(cwd, project) : undefined;
    const flatDependencies = await getFlatDependencies(cwd, project, stripBasePath, options);
    const server = await server_1.createServer(flatDependencies);
    await server.listen(port);
    exports.startServeMessage(`http://localhost:${port}`);
};
exports.startLoadFileServe = async (filename, cwd, port = 7000) => {
    const source = path.resolve(cwd, filename);
    if (!filesystem_1.existFile(source)) {
        console.log(chalk_1.default.black.bgRed(" Not fount "), chalk_1.default.red(`${source}`));
        process.exit();
    }
    else {
        console.log(chalk_1.default.black.bgGreen(" Load "), chalk_1.default.green(`${source}`));
    }
    const csrProps = require(source);
    const server = await server_1.createServer(() => Promise.resolve(csrProps.flatDependencies));
    await server.listen(port);
    exports.startServeMessage(`http://localhost:${port}`);
};
exports.outputCsrProps = async (file, cwd, options, cut, output) => {
    const stripBasePath = cut ? getBasePath(cwd, file) : undefined;
    const source = path.resolve(cwd, path.normalize(file));
    const flatDependencies = await map_1.getDependencies({ source, executeDirectory: cwd, stripBasePath }, options);
    if (output) {
        const outputFile = path.resolve(cwd, output);
        const csrProps = { flatDependencies };
        filesystem_1.mkdirP(path.dirname(outputFile));
        fs.writeFileSync(outputFile, JSON.stringify(csrProps, null, 2), { encoding: "utf-8" });
        console.log(chalk_1.default.black.bgGreen(" Save "), chalk_1.default.green(`${outputFile}`));
        console.log("");
        console.log("      ", `Strip Base Path: ${cut ? stripBasePath : "no striped"}`);
        console.log("");
    }
};
