"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const view_1 = require("@code-dependency/view");
const path = require("path");
const pretty = require("pretty");
const server_1 = require("react-dom/server");
const url = require("url");
const filesystem_1 = require("./filesystem");
const generateConfig = (config) => {
    return {
        projects: [],
        ...config,
    };
};
const saveHtml = (assetsManifest, { publicPath, staticDist, ...option }) => {
    const join = (relativePath) => {
        if (new RegExp(/^https?:\/\//).test(publicPath)) {
            return url.resolve(publicPath, relativePath);
        }
        return path.join(publicPath, relativePath);
    };
    const assets = {
        css: [],
        js: [],
        manifest: join("/manifest.json"),
        favicon: join("/favicon.ico"),
    };
    const site = {
        publicPath,
        configJson: join("config.json"),
        debugApi: join("api"),
        projectBasePath: publicPath,
    };
    assets.css.push(join(assetsManifest["index.css"]));
    assets.js.push(join(assetsManifest["runtime~index.js"]));
    assets.js.push(join(assetsManifest["vendors~index.js"]));
    assets.js.push(join(assetsManifest["index.js"]));
    const html = "<!DOCTYPE html>\n" + server_1.renderToStaticMarkup(view_1.generateHtml(assets, site, option));
    filesystem_1.saveFileSync(path.join(staticDist, "index.html"), pretty(html));
};
exports.distribution = async (options) => {
    console.log("");
    console.log("Distribution Setting");
    console.log(`   public path : ${options.publicPath}`);
    console.log(`   dist path   : ${options.staticDist}`);
    console.log("");
    const isAbsolutePath = options.staticDist.startsWith("/") || options.staticDist.startsWith("~");
    const distPath = isAbsolutePath ? options.staticDist : path.join(process.cwd(), options.staticDist);
    const configPath = path.join(distPath, "config.json");
    const config = generateConfig(filesystem_1.readConfig(configPath));
    filesystem_1.mkdirP(distPath);
    const viewPaths = view_1.getPaths();
    await filesystem_1.copyAssetFiles(viewPaths.build, distPath, [".css", ".js", ".json"]);
    filesystem_1.mkdirP(path.join(distPath, "projects"));
    const assetsManifest = filesystem_1.readConfig(viewPaths["asset-manifest"].json);
    if (assetsManifest) {
        saveHtml(assetsManifest, options);
    }
    filesystem_1.saveConfig(configPath, config);
};
