"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const path = require("path");
exports.existFile = (filename) => {
    return fs.existsSync(filename) && fs.statSync(filename).isFile();
};
const isDirectory = (dirname) => {
    return fs.existsSync(dirname) && fs.statSync(dirname).isDirectory();
};
exports.mkdirP = (dirPath) => {
    if (!fs.existsSync(dirPath) || !fs.statSync(dirPath).isDirectory()) {
        console.log(`Make dir : ${dirPath}`);
        fs.mkdirSync(dirPath, { recursive: true });
    }
    else {
        console.log(`Already exists: ${dirPath}`);
    }
};
exports.saveFileSync = (filename, data) => {
    console.log(`Save: ${filename}`);
    fs.writeFileSync(filename, data, { encoding: "utf-8" });
};
exports.readConfig = (filename) => {
    if (!exports.existFile(filename)) {
        return;
    }
    try {
        return JSON.parse(fs.readFileSync(filename, { encoding: "utf-8" }));
    }
    catch (e) {
        console.error(e);
    }
    return undefined;
};
exports.saveConfig = (filename, config) => {
    try {
        fs.writeFileSync(filename, JSON.stringify(config, null, 2), { encoding: "utf-8" });
    }
    catch (e) {
        console.error(e);
    }
};
exports.copyAssetFiles = async (source, destination, extensions) => {
    console.log("");
    console.log(`  Copy  `);
    console.log(`      from ${source}`);
    console.log(`      to   ${destination}`);
    console.log("");
    await fs.copy(source, destination, {
        filter: (targetPath) => {
            return isDirectory(targetPath) || extensions.includes(path.extname(targetPath));
        },
        recursive: true,
    });
};
