#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander = require("commander");
const path = require("path");
const command_1 = require("./command");
const distribution_1 = require("./distribution");
process.on("unhandledRejection", console.dir);
const executeCommandLine = () => {
    const pkg = require(path.resolve(__dirname, "../package.json"));
    commander
        .version(pkg.version)
        .option("-f --file [value]", "Select your file.")
        .option("-o --output [value]", "Output file path.")
        .option("-s --serve", "Start server")
        .option("-i --input [value]", "input file.")
        .option("-c --cut", "cut base path.")
        .option("-p --project [value]", "project path.")
        .option("--static-dist [value]", "static distribution path")
        .option("--public-path [value", "public base path")
        .parse(process.argv);
    return commander;
};
const main = async () => {
    const option = executeCommandLine();
    const cwd = process.cwd();
    const resolveOption = {
        alias: {},
        extensions: [".js", ".mjs", ".jsx", ".vue", ".ts", ".tsx", ".d.ts", ".coffee", ".litcoffee", ".coffee.md", ".csx", ".cjsx"],
    };
    if (option.args.length >= 1 && typeof option.args[0] === "string") {
        return command_1.startProjectServe(option.args[0], cwd, resolveOption, true);
    }
    if (option.serve && option.project) {
        return command_1.startProjectServe(option.project, cwd, resolveOption, option.cut);
    }
    else if (option.serve && option.input) {
        return command_1.startLoadFileServe(option.input, cwd);
    }
    else if (option.file) {
        return command_1.outputCsrProps(option.file, cwd, resolveOption, !!option.cut, option.output);
    }
    else if (option.staticDist) {
        const publicPath = option.publicPath ? (option.publicPath.endsWith("/") ? option.publicPath : option.publicPath + "/") : "/";
        return distribution_1.distribution({ staticDist: option.staticDist, title: "code-dependency", publicPath });
    }
};
main();
