"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const View = require("@code-dependency/view");
const express = require("express");
const fs = require("fs");
const path = require("path");
const filesystem_1 = require("./filesystem");
exports.createServer = async (generateFlatDependencies) => {
    const app = express();
    const viewPaths = View.getPaths();
    const generateProps = async () => {
        return {
            flatDependencies: await generateFlatDependencies(),
        };
    };
    const applyProps = async () => {
        const props = await generateProps();
        const template = fs.readFileSync(viewPaths.index.html, { encoding: "utf-8" });
        return template.replace("{{ SSR_DOM }}", "").replace('"SSR_INITIAL_STATE"', JSON.stringify(props));
    };
    app.use("/static", express.static(viewPaths.static));
    app.use("/manifest.json", express.static(viewPaths.manifest.json));
    app.get("/api", async (req, res) => {
        await generateProps().then(props => {
            res.header("Access-Control-Allow-Origin", "*");
            res.header("Access-Control-Allow-Headers", "Origin, X-Requested-With, Content-Type, Accept");
            res.json(props);
            res.end();
        });
    });
    app.get("/config.json", async (req, res) => {
        res.header("Access-Control-Allow-Origin", "*");
        res.header("Access-Control-Allow-Headers", "Origin, X-Requested-With, Content-Type, Accept");
        const config = filesystem_1.readConfig(path.join(process.cwd(), "./dist/config.json"));
        res.send(JSON.stringify(config));
        res.end();
    });
    app.get("/projects/:projectName", async (req, res) => {
        res.header("Access-Control-Allow-Origin", "*");
        res.header("Access-Control-Allow-Headers", "Origin, X-Requested-With, Content-Type, Accept");
        const config = filesystem_1.readConfig(path.join(process.cwd(), "./dist/projects", req.params.projectName));
        if (config) {
            res.send(JSON.stringify(config));
        }
        else {
            res.send(`Not found ${req.params.projectName}`);
        }
        res.end();
    });
    app.get("*", async (req, res) => {
        applyProps().then(result => {
            res.send(result);
            res.end();
        });
    });
    return app;
};
